import argparse

from blueness import module
from blueness.argparse.generic import sys_exit

from bluer_sandbox import NAME
from bluer_sandbox.offline_llm.model.functions import get
from bluer_sandbox.logger import logger

NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    help="get",
)
parser.add_argument(
    "--what",
    type=str,
    help="filename | object_name | repo_name",
    default="object",
)
parser.add_argument(
    "--tiny",
    type=int,
    help="0 | 1",
    default=0,
)
args = parser.parse_args()

success = False
if args.task == "get":
    success = True
    print(
        get(
            what=args.what,
            tiny=args.tiny == 1,
        )
    )
else:
    success = None

sys_exit(logger, NAME, args.task, success)



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_seed(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("screen", mono=mono)

    return show_usage(
        [
            "@arvan",
            "seed",
            f"[{options}]",
        ],
        "seed 🌱  arvancloud.",
        mono=mono,
    )


def help_ssh(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun,~seed", mono=mono)

    return show_usage(
        [
            "@arvan",
            "ssh",
            f"[{options}]",
            "<ip-address>",
        ],
        "ssh to arvancloud.",
        mono=mono,
    )


help_functions = {
    "seed": help_seed,
    "ssh": help_ssh,
}



from typing import List

from bluer_options.terminal import show_usage


def help(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@sandbox",
            "interview",
            "<what>",
            "<args>",
        ],
        "interview/<what> <args>.",
        mono=mono,
    )


help_functions = {
    "": help,
}
